@@ -12,6 +12,7 @@ Graphical user interface must implement all these functions.
 //These are different state of Game.
 enum {
   SCREEN_WELCOME = 0,
+  SCREEN_PASSWORD_TYPING,
   SCREEN_GAME_SELECTION, //This is main-menu
   SCREEN_THEME_SELECTION,
   SCREEN_COMPOSING,
@@ -19,14 +20,10 @@ enum {
   SCREEN_SONG_RECORDING,
   SCREEN_PLAY_RECORDED,
   SCREEN_MIDI_EDITOR,
+  SCREEN_SEQUENCER,
   NUMBER_OF_SCREENS, //Keep this entry last.
 };
 
-void gui_go_screen(int number);
-void gui_init();
-void gui_visualize_playing();
-void gui_visualize_contour(float freq);
 
-void gui_start_main_loop();
 
 #endif /*  _GUI_H_  */
