@@ -9,8 +9,9 @@
  */
 
 #include "jammo-sample-button.h"
+#include <string.h>
 
-G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_BUTTON);
+G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_DRAGGABLE_ACTOR);
 
 enum {
 	PROP_0,
@@ -24,19 +25,21 @@ struct _JammoSampleButtonPrivate {
 	JammoSample* sample;
 };
 
-JammoSampleButton* jammo_sample_button_new() {
+static gboolean on_clicked(TangleButton* button, gpointer user_data);
 
-	return JAMMO_SAMPLE_BUTTON(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, NULL));
+ClutterActor* jammo_sample_button_new() {
+
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, NULL));
 }
 
-JammoSampleButton* jammo_sample_button_new_from_files(const gchar* image_filename, const gchar* sample_filename) {
+ClutterActor* jammo_sample_button_new_from_files(const gchar* image_filename, const gchar* sample_filename) {
 
-	return JAMMO_SAMPLE_BUTTON(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", image_filename, "sample-filename", sample_filename, NULL));
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", image_filename, "sample-filename", sample_filename, NULL));
 }
 
-JammoSampleButton* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
+ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
 
-	return JAMMO_SAMPLE_BUTTON(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, NULL));
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, NULL));
 }
 
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button) {
@@ -60,8 +63,8 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 		g_free(sample_button->priv->image_filename);
 		sample_button->priv->image_filename = g_strdup(image_filename);
 
-		tangle_button_set_normal_actor(TANGLE_BUTTON(sample_button),
-		                               clutter_texture_new_from_file(image_filename, NULL));
+		tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))),
+		                                          clutter_texture_new_from_file(image_filename, NULL));
 
 		g_object_notify(G_OBJECT(sample_button), "image-filename");
 	}
@@ -86,8 +89,8 @@ void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSampl
 		if (sample_button->priv->sample) {
 			g_object_unref(sample_button->priv->sample);
 		}
-		g_object_ref(sample);
-		sample_button->priv->sample = sample;
+		sample_button->priv->sample = jammo_sample_new_from_existing(sample);
+		g_object_ref(sample_button->priv->sample);
 		
 		g_object_notify(G_OBJECT(sample_button), "sample-filename");
 		g_object_notify(G_OBJECT(sample_button), "sample");
@@ -95,6 +98,20 @@ void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSampl
 	}
 }
 
+static GObject* jammo_sample_button_constructor(GType type, guint n_construct_properties, GObjectConstructParam* construct_properties) {
+	GObject* object;
+	ClutterActor* button;
+
+	button = tangle_button_new();
+	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(button), TRUE);
+
+	object = tangle_construct_with_extra_properties(G_OBJECT_CLASS(jammo_sample_button_parent_class)->constructor, type, n_construct_properties, construct_properties, "wrapped", button, NULL);
+
+	g_signal_connect(button, "clicked", G_CALLBACK(on_clicked), object);
+
+	return object;
+}
+
 static void jammo_sample_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoSampleButton* sample_button;
 	
@@ -148,6 +165,7 @@ static void jammo_sample_button_dispose(GObject* object) {
 static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(klass);
 
+	gobject_class->constructor = jammo_sample_button_constructor;
 	gobject_class->finalize = jammo_sample_button_finalize;
 	gobject_class->dispose = jammo_sample_button_dispose;
 	gobject_class->set_property = jammo_sample_button_set_property;
@@ -161,7 +179,7 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
 	                                "Image filename",
 	                                "The filename of the displayed image",
 					NULL,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoSampleButton:sample-filename:
@@ -171,7 +189,7 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
 	                                "Sample filename",
 	                                "The filename of the played sample",
 					NULL,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoSampleButton:sample:
@@ -181,12 +199,21 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
 	                                "Sample",
 	                                "The JammoSample that is played when the button is interacting",
 	                                JAMMO_TYPE_SAMPLE,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private(gobject_class, sizeof(JammoSampleButtonPrivate));
 }
 
-static void jammo_sample_button_init(JammoSampleButton* samplebutton) {
-	samplebutton->priv = G_TYPE_INSTANCE_GET_PRIVATE(samplebutton, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
+static void jammo_sample_button_init(JammoSampleButton* sample_button) {
+	sample_button->priv = G_TYPE_INSTANCE_GET_PRIVATE(sample_button, JAMMO_TYPE_SAMPLE_BUTTON, JammoSampleButtonPrivate);
+}
+
+static gboolean on_clicked(TangleButton* button, gpointer user_data) {
+	JammoSampleButton* sample_button;
+	
+	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
+	jammo_sample_play(sample_button->priv->sample);
+	
+	return FALSE;
 }
 
