@@ -116,10 +116,15 @@ return FALSE;
 gchar* GLOBAL_CHAR;
 ClutterActor* GLOBAL_ACTOR;
 static void song_view_showed(TangleAction* action, GObject* source, const gchar* trigger, TangleProperties* properties){
+	printf("song_view_showed\n");
+	gchar *filepath1;
+	filepath1 =  g_strdup_printf("mentor_speech/mentor_song_%s_fi.ogg", chum_get_current_song());
+	
+	printf("pass to mentor: '%s' \n",filepath1);
 	ClutterActor* new_parent= GLOBAL_ACTOR;
 	ClutterActor *temp_bear=mentor_give_temp_bear();
 	clutter_container_add_actor (CLUTTER_CONTAINER (new_parent), temp_bear);
-	mentor_speech(temp_bear,GLOBAL_CHAR);
+	mentor_speech(temp_bear,filepath1);
 }
 
 
@@ -143,10 +148,7 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	
 	
 	gchar *filepath1;
-	filepath1= g_strdup_printf("mentor_speech/mentor_song_%s_fi.ogg", name);
-	//if not found, use mentor_speech/mentor_songmissing_fi.ogg
-	GLOBAL_CHAR=filepath1;
-	GLOBAL_ACTOR=view;
+	GLOBAL_ACTOR=view; //FIXME. view is not passed with g_signal_connect
 	g_signal_connect(view, "transition-completed", G_CALLBACK(song_view_showed), NULL);
 	
 	
