@@ -65,8 +65,10 @@ chum_stop_sequencer();
 chum_go_screen(SCREEN_THEME_SELECTION);
 }
 
+extern char *name_of_states[]; //This is not really used, just for test.
+extern int state_of_chum;   //Mentor needs to know this.
 void mentor_pressed(){
-printf("mentor_pressed\n");
+printf("MENTOR SAY:You are now in %s\n",name_of_states[state_of_chum]);
 }
 
 void do_play_button_press()  {
@@ -131,14 +133,19 @@ ClutterColor trans_color = { 0, 0, 0, 0x00 };
 ClutterColor dark_color =  { 0, 0, 0, 0xdd };
 ClutterColor white_color = { 0, 0, 0, 0xbb };
 ClutterColor blue_color =  { 0, 0, 0xff, 0xff };
-ClutterColor green_color =  { 158, 219, 116, 0xff };
+ClutterColor sing_green_color =  { 158, 219, 116, 0xff }; /*This is for background of singing game*/
+ClutterColor black_color = { 0, 0, 0, 0xff };
+ClutterColor green_color = { 0, 0xff, 0, 0xff };
 
 
 ClutterColor *get_transparency_color(){ return &trans_color; }
 ClutterColor *get_white_color(){        return &white_color; }
 ClutterColor *get_dark_color(){         return &dark_color;  }
 ClutterColor *get_blue_color(){         return &blue_color;  }
-ClutterColor *get_green_color(){         return &green_color;  }
+ClutterColor *get_sing_green_color(){         return &sing_green_color;  }
+ClutterColor *get_black_color(){		return &black_color; }
+ClutterColor *get_green_color(){		return &green_color; }
+
 
 
 void gui_visualize_playing(int state) {
